# commonutil-net-fileservice

This package provides helper routines for setting up file upload-and-process service.

## Limitation

Nested rsync target folder is not supported. File update detection will not work correctly.
